MetaQuota
================================

.. currentmodule:: alfred3_interact.quota

.. autoclass:: MetaQuota
   :show-inheritance:




   .. rubric:: Methods

   .. autosummary::
      :nosignatures:
      :toctree:









   .. rubric:: Attributes

   .. autosummary::
      :template: autosummary/attribute.rst
      :toctree:


         ~MetaQuota.allfinished
         ~MetaQuota.full
         ~MetaQuota.nfinished
         ~MetaQuota.nopen
         ~MetaQuota.npending
         ~MetaQuota.nslots
